| InterCell-class | R Documentation |
The InterCell object is used to in all the analysis InterCellDB provided. It incoporates the necessary databases, and stores every important intermediate result.
fgenesInterCellDB needs the differential expressed genes and their belonging clusters as input. The given data need to have columns named 'gene', 'cluster', 'LogFC', 'PVal'. Those each means, 'gene': the authorized gene names, 'cluster': cell cluster, 'LogFC': the log transformed fold change of genes, 'PVal': the P val for regarding one gene as differentially expressed one. The expression level of each gene is also needed when statistical test is required and it should be stored in column named 'Exprs'.
databaseDatabase stored in InterCellDBPack object.
formulaeThe default formulae to be used in analysis.
inter.fullviewThis is used to store the result of network analysis.
tg.itinfoThis stores information about one intercellular communication.
tg.action.pairsThis is used to store the intermediate result of action properties and gene pairs.
tg.veinfoThis is used to store the intermediate result of one intercellular communication (for one interacting 2-cell group).
tg.action.compThis is used to store the result of analyzing composition of action mode and action effect in one interacellular communication.
tg.spgenesThis is used to store the selected gene pairs and all their participating interacitons in one intercellular communication.
tool.varsThis stores several variables to be used embedded in program.
miscThe not important intermediate result will be put in this parameter as well as some pre-defined settings.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.