| InterCellDBPack-class | R Documentation |
The InterCellDBPack class provides a standard storage format of all databases for running analysis.
This object is mostly created along with InterCell-class.
Users need to specify the species firstly. Then, user-defined subset of database could be
collected by function SelectDBSubset.
speciesInterCellDB only allows 'human' and 'mouse' species.
genes.dbThe gene reference database, which is generated from NCBI gene site. It records all the authorized gene names.
pairs.dbThe database records all gene pairs, which are transferred from protein interaction database - 'STRING'.
actions.dbThe database records all action properties (including 'action.mode', 'action.effect') for gene pairs in slot:'pairs.db'.
anno.location.dbThe database collects all subcellular location from COMPARTMENTS for genes in slot:'pairs.db'.
anno.type.dbThe database collects all molecular function from Uniprot for genes in slot:'pairs.db'.
go.ref.dbThe database collects all GO terms for genes in slot:'pairs.db'.
accessory.dbA list of accessory database, for example, the mapping list of raw keywords from Uniport.
miscThe preserved area for miscellaneous things. Currently no usage.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.