| kpred.action.effect | R Documentation |
kpred.action.effect is extracted from databases depicting action effect of actions for functional usages.
kpred.color.effect is aligned with kpred.action.effect one-to-one. In default setting,
the color used for action effect in plotting will use colors listed in this variable.
kpred.ext.action.effect is the extended format, which depicts action effect and direction of action together,
and extends action effect to 7 different types.
kpred.color.ext.effect is aligned with kpred.ext.action.effect one-to-one. In default setting,
the color used for extened action effect in plotting will use colors listed in this variable.
kpred.action.effect
kpred.color.effect
kpred.ext.action.effect
kpred.color.ext.effect
An object of class character of length 4.
An object of class character of length 4.
An object of class character of length 7.
An object of class character of length 7.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.